==> haskell-network-udp-0.0.0-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-2S63LpP7oxW2uBPsWtClnq
key:                  network-udp-0.0.0-2S63LpP7oxW2uBPsWtClnq
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  44a1e24059ab03b838e2d0a0e4b212c0
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-2S63LpP7oxW2uBPsWtClnq
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-Ah02L91k7FF1gTzYMpHvN0
    network-3.1.4.0-CjG4q0LIF56BxDJPM1CXeZ

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-udp-0.0.0-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-GHob9cWCa8JA0pR1SHTvhQ
key:                  network-udp-0.0.0-GHob9cWCa8JA0pR1SHTvhQ
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  707c27e69bb0cbf6ae23871007a7bb9b
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-GHob9cWCa8JA0pR1SHTvhQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-1N8feKeEkWfHpWNcPqsz2u
    network-3.1.4.0-F6j0uAI5udHBrXI4nYArv7

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
